@@ -7,6 +7,6 @@
 
 __author__ = "Sqreen"
 __copyright__ = "Copyright 2016 - 2020, Sqreen"
-__email__ = "contact@sqreen.io"
+__email__ = "contact@sqreen.com"
 __license__ = "proprietary"
-__version__ = "1.19.0"
+__version__ = "1.21.0"
