@@ -9,17 +9,17 @@
 import json
 import logging
 from copy import copy
-from itertools import groupby
+from itertools import chain, groupby
 from operator import itemgetter
 
 from sqreen.performance_metrics import PerformanceMetricsSettings
 
 from . import config
-from .actions import ACTION_STORE
 from .rules_callbacks import cb_from_rule
 from .runtime_storage import runtime
 from .sdk.events import STACKTRACE_EVENTS
 from .signature import RSAVerifier
+from .utils import Mapping
 
 LOGGER = logging.getLogger(__name__)
 
@@ -184,26 +184,22 @@ def _load_rules(runner, params=None, check_signature=True, storage=runtime):
 
     # Create the callbacks
     callbacks = []
+    if runner.interface_manager is not None:
+        LOGGER.debug("Loading ecosystem callbacks")
+        callbacks.extend(chain.from_iterable(
+            runner.interface_manager.call_all("instrumentation_callbacks", runner, storage)))
+
     for rule_dict in rules:
         # Instantiate the rule callback
         callback = cb_from_rule(rule_dict, runner, verifier, storage=storage)
+        if callback:
+            LOGGER.debug("Instantiate rule %r", callback)
+            callbacks.append(callback)
 
-        # Check if the rule has some metrics to register
+        # Check if the rule has some metrics to register (even if not loaded)
         for metric in rule_dict.get("metrics", []):
             runner.metrics_store.register_metric(**metric)
 
-        if callback:
-            LOGGER.debug(
-                'Rule "%s" will hook on "%s %s" with callback %s with strategy %s',
-                callback.rule_name,
-                callback.hook_module,
-                callback.hook_name,
-                callback,
-                callback.strategy,
-            )
-
-            callbacks.append(callback)
-
     return rulespack_id, callbacks
 
 
@@ -278,7 +274,7 @@ def actions_reload(runner, params=None):
     actions = data["actions"]
     LOGGER.debug("Reloading actions %s", actions)
 
-    unsupported = ACTION_STORE.reload_from_dicts(actions or [])
+    unsupported = runner.action_store.reload_from_dicts(actions or [])
     if unsupported:
         return {
             "status": False,
@@ -327,10 +323,19 @@ def features_change(runner, params):
     # Always set the new value of whitelisted_metric
     runner.set_whitelisted_metric(params.get("whitelisted_metric", True))
 
+    # Enable the signal client
+    use_signals = params.get("use_signals")
+    if use_signals is not None:
+        runner.set_signal_client(
+            params.get("batch_size", 0), params.get("max_staleness", 0),
+            use_signals=use_signals,
+        )
+
     # Alter the deliverer if the batch_size is set
     if params.get("batch_size") is not None:
         runner.set_deliverer(
-            params["batch_size"], params.get("max_staleness", 0)
+            params["batch_size"], params.get("max_staleness", 0),
+            use_signals=use_signals or False,
         )
 
     new_features = copy(runner.features_get())
@@ -377,6 +382,35 @@ def force_logout(runner, params=None):
     return {"status": True}
 
 
+def tracing_enable(runner, params):
+    """ Set the tracing identifier and scope definition.
+    """
+    if len(params) != 2:
+        return {
+            "status": False,
+            "output": {"error": "wrong number of parameters"},
+        }
+
+    tracing_identifier = params[0]
+    tracing_scope_definition = params[1]
+
+    if not isinstance(tracing_identifier, str) or not isinstance(tracing_scope_definition, Mapping):
+        return {
+            "status": False,
+            "output": {"error": "wrong parameter types"},
+        }
+
+    try:
+        runner.set_tracing_configuration(tracing_identifier, tracing_scope_definition)
+    except ValueError as e:
+        return {
+            "status": False,
+            "output": {"error": str(e)},
+        }
+    else:
+        return {"status": True}
+
+
 ALL_COMMANDS = {
     "instrumentation_enable": instrumentation_enable,
     "instrumentation_remove": instrumentation_remove,
@@ -390,5 +424,6 @@ ALL_COMMANDS = {
     "force_logout": force_logout,
     "actions_reload": actions_reload,
     "record_stacktrace": record_stacktrace,
+    "tracing_enable": tracing_enable,
 }
 COALESCE_COMMANDS = ("actions_reload", "rules_reload",)
